@@ -161,7 +161,7 @@ class Device:
         traits = event_message.resource_update_traits
         if not traits:
             return
-        _LOGGER.debug("Trait update %s", traits.keys())
+        _LOGGER.debug("Trait update %s", traits)
         for (trait_name, trait) in traits.items():
             # Discard updates older than prior events
             # Note: There is still a race where traits read from the API on
@@ -178,10 +178,6 @@ class Device:
     def event_media_manager(self) -> EventMediaManager:
         return self._event_media_manager
 
-    def active_events(self, event_types: list) -> dict:
-        """Return any active events for the specified trait names."""
-        return self._event_media_manager.active_events(event_types)
-
     @property
     def active_event_trait(self) -> Optional[EventTrait]:
         """Return trait with the most recently received active event."""
