@@ -7,9 +7,9 @@ import logging
 from abc import ABC
 from collections import OrderedDict
 from collections.abc import Iterable
-from typing import Any, Awaitable, Callable, Dict, Optional
+from typing import Any, Awaitable, Callable, Dict
 
-from .camera_traits import EventImageGenerator, EventImageType
+from .camera_traits import EventImageContentType, EventImageGenerator, EventImageType
 from .event import (
     CameraMotionEvent,
     CameraPersonEvent,
@@ -76,7 +76,9 @@ class CachePolicy:
 class Media:
     """Represents media related to an event."""
 
-    def __init__(self, contents: bytes, event_image_type: EventImageType) -> None:
+    def __init__(
+        self, contents: bytes, event_image_type: EventImageContentType
+    ) -> None:
         """Initialize Media."""
         self._contents = contents
         self._event_image_type = event_image_type
@@ -87,7 +89,7 @@ class Media:
         return self._contents
 
     @property
-    def event_image_type(self) -> EventImageType:
+    def event_image_type(self) -> EventImageContentType:
         """Content event image type of the media."""
         return self._event_image_type
 
@@ -133,7 +135,7 @@ class EventMediaStore(ABC):
     async def async_load(self) -> dict | None:
         """Load data."""
 
-    async def async_save(self, data: dict | None) -> None:
+    async def async_save(self, data: dict) -> None:
         """Save data."""
 
     def get_media_key(self, device_id: str, event: ImageEventBase) -> str:
@@ -160,7 +162,7 @@ class InMemoryEventMediaStore(EventMediaStore):
         """Load data."""
         return self._data
 
-    async def async_save(self, data: dict | None) -> None:
+    async def async_save(self, data: dict) -> None:
         """Save data."""
         self._data = data
 
@@ -212,7 +214,9 @@ class EventMediaModelItem:
             event.session_events = list(events.values())
             event.event_image_type = event_image_type
         return EventMediaModelItem(
-            data["event_session_id"], events, data.get("media_key")
+            data["event_session_id"],
+            events,
+            data.get("media_key"),
         )
 
     @property
@@ -326,11 +330,8 @@ class EventMediaManager:
         await self._cache_policy._store.async_save(store_data)
 
     async def get_media(
-        self,
-        event_session_id: str,
-        width: Optional[int] = None,
-        height: Optional[int] = None,
-    ) -> Optional[EventMedia]:
+        self, event_session_id: str, width: int | None = None, height: int | None = None
+    ) -> EventMedia | None:
         """Get media for the specified event.
 
         Note that the height and width hints are best effort and may not be
@@ -348,30 +349,26 @@ class EventMediaManager:
             return None
         _LOGGER.debug("Fetching media for event_session_id=%s", event_session_id)
         if item.media_key:
-            media_key = item.media_key
-        else:
-            media_key = self._cache_policy._store.get_media_key(self._device_id, event)
-
-        contents = await self._cache_policy._store.async_load_media(media_key)
-        if contents is None:
-            if event.is_expired:
-                _LOGGER.debug(
-                    "Skipping fetch; Event expired; event_session_id=%s",
-                    event_session_id,
-                )
-                return None
-            if not (generator := self._event_trait_map.get(event.event_type)):
-                return None
-            event_image = await generator.generate_event_image(event)
-            if not event_image:
-                return None
-            contents = await event_image.contents(width=width, height=height)
-            await self._cache_policy._store.async_save_media(media_key, contents)
-
-        if not item.media_key:
-            item.media_key = media_key
-            await self._async_update(event_data)
+            contents = await self._cache_policy._store.async_load_media(item.media_key)
+            if contents:
+                return item.get_event_media(contents)
 
+        if event.is_expired:
+            _LOGGER.debug(
+                "Skipping fetch; Event expired; event_session_id=%s",
+                event_session_id,
+            )
+            return None
+        if not (generator := self._event_trait_map.get(event.event_type)):
+            return None
+        event_image = await generator.generate_event_image(event)
+        if not event_image:
+            return None
+        contents = await event_image.contents(width=width, height=height)
+        media_key = self._cache_policy._store.get_media_key(self._device_id, event)
+        await self._cache_policy.store.async_save_media(media_key, contents)
+        item.media_key = media_key
+        await self._async_update(event_data)
         return item.get_event_media(contents)
 
     async def async_events(self) -> Iterable[ImageEventBase]:
@@ -475,18 +472,8 @@ class EventMediaManager:
         if valid_events > 0:
             await self._callback(event_message)
 
-    def active_events(self, event_types: list) -> Dict[str, ImageEventBase]:
-        """Return any active events for the specified trait names."""
-        active_events = {}
-        for event_type in event_types:
-            trait = self._event_trait_map.get(event_type)
-            if not trait or not trait.active_event:
-                continue
-            active_events[event_type] = trait.active_event
-        return active_events
-
     @property
-    def active_event_trait(self) -> Optional[EventImageGenerator]:
+    def active_event_trait(self) -> EventImageGenerator | None:
         """Return trait with the most recently received active event."""
         trait_to_return: EventImageGenerator | None = None
         for trait in self._event_trait_map.values():
@@ -501,3 +488,14 @@ class EventMediaManager:
                 if event.expires_at > trait_to_return.last_event.expires_at:
                     trait_to_return = trait
         return trait_to_return
+
+    async def get_active_event_media(
+        self, width: int | None = None, height: int | None = None
+    ) -> EventMedia | None:
+        """Return a snapshot image for a very recent event if any."""
+        if not (trait := self.active_event_trait):
+            return None
+        event: ImageEventBase | None = trait.last_event
+        if not event:
+            return None
+        return await self.get_media(event.event_session_id, width, height)
